@@ -102,7 +102,7 @@ def test_raise_for_status():
         response.raise_for_status()
     assert str(exc_info.value) == (
         "Informational response '101 Switching Protocols' for url 'https://example.org'\n"
-        "For more information check: https://httpstatuses.com/101"
+        "For more information check: https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/101"
     )
 
     # 3xx status codes are redirections.
@@ -114,7 +114,7 @@ def test_raise_for_status():
     assert str(exc_info.value) == (
         "Redirect response '303 See Other' for url 'https://example.org'\n"
         "Redirect location: 'https://other.org'\n"
-        "For more information check: https://httpstatuses.com/303"
+        "For more information check: https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/303"
     )
 
     # 4xx status codes are a client error.
@@ -125,7 +125,7 @@ def test_raise_for_status():
         response.raise_for_status()
     assert str(exc_info.value) == (
         "Client error '403 Forbidden' for url 'https://example.org'\n"
-        "For more information check: https://httpstatuses.com/403"
+        "For more information check: https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/403"
     )
 
     # 5xx status codes are a server error.
@@ -136,7 +136,7 @@ def test_raise_for_status():
         response.raise_for_status()
     assert str(exc_info.value) == (
         "Server error '500 Internal Server Error' for url 'https://example.org'\n"
-        "For more information check: https://httpstatuses.com/500"
+        "For more information check: https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/500"
     )
 
     # Calling .raise_for_status without setting a request instance is
@@ -298,6 +298,23 @@ def test_response_force_encoding():
     assert response.encoding == "iso-8859-1"
 
 
+def test_response_force_encoding_after_text_accessed():
+    response = httpx.Response(
+        200,
+        content=b"Hello, world!",
+    )
+    assert response.status_code == 200
+    assert response.reason_phrase == "OK"
+    assert response.text == "Hello, world!"
+    assert response.encoding == "utf-8"
+
+    with pytest.raises(ValueError):
+        response.encoding = "UTF8"
+
+    with pytest.raises(ValueError):
+        response.encoding = "iso-8859-1"
+
+
 def test_read():
     response = httpx.Response(
         200,
@@ -380,17 +397,18 @@ def test_iter_raw():
 
 def test_iter_raw_with_chunksize():
     response = httpx.Response(200, content=streaming_body())
-
     parts = [part for part in response.iter_raw(chunk_size=5)]
     assert parts == [b"Hello", b", wor", b"ld!"]
 
     response = httpx.Response(200, content=streaming_body())
+    parts = [part for part in response.iter_raw(chunk_size=7)]
+    assert parts == [b"Hello, ", b"world!"]
 
+    response = httpx.Response(200, content=streaming_body())
     parts = [part for part in response.iter_raw(chunk_size=13)]
     assert parts == [b"Hello, world!"]
 
     response = httpx.Response(200, content=streaming_body())
-
     parts = [part for part in response.iter_raw(chunk_size=20)]
     assert parts == [b"Hello, world!"]
 
@@ -596,6 +614,14 @@ def test_iter_text_with_chunk_size():
     parts = [part for part in response.iter_text(chunk_size=5)]
     assert parts == ["Hello", ", wor", "ld!"]
 
+    response = httpx.Response(200, content=b"Hello, world!!")
+    parts = [part for part in response.iter_text(chunk_size=7)]
+    assert parts == ["Hello, ", "world!!"]
+
+    response = httpx.Response(200, content=b"Hello, world!")
+    parts = [part for part in response.iter_text(chunk_size=7)]
+    assert parts == ["Hello, ", "world!"]
+
     response = httpx.Response(200, content=b"Hello, world!")
     parts = [part for part in response.iter_text(chunk_size=13)]
     assert parts == ["Hello, world!"]
